@@ -771,8 +771,10 @@ cd_util_get_sensor_reading (CdUtilPrivate *priv, gchar **values, GError **error)
 						 cap,
 						 NULL,
 						 error);
-		if (!ret)
+		if (xyz == NULL) {
+			ret = FALSE;
 			goto out;
+		}
 
 		/* unlock */
 		ret = cd_sensor_unlock_sync (sensor,
@@ -1037,7 +1039,7 @@ cd_util_create_profile (CdUtilPrivate *priv, gchar **values, GError **error)
 	gboolean ret = TRUE;
 	guint mask;
 
-	if (g_strv_length (values) < 3) {
+	if (g_strv_length (values) < 2) {
 		ret = FALSE;
 		g_set_error_literal (error,
 				     1, 0,
@@ -1086,7 +1088,30 @@ cd_util_device_add_profile (CdUtilPrivate *priv, gchar **values, GError **error)
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[1])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[1]);
+		goto out;
+	}
+
 	device = cd_device_new_with_object_path (values[0]);
+	ret = cd_device_connect_sync (device, NULL, error);
+	if (!ret)
+		goto out;
 	profile = cd_profile_new_with_object_path (values[1]);
 	ret = cd_device_add_profile_sync (device,
 					  CD_DEVICE_RELATION_HARD,
@@ -1123,7 +1148,30 @@ cd_util_device_make_profile_default (CdUtilPrivate *priv, gchar **values, GError
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[1])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[1]);
+		goto out;
+	}
+
 	device = cd_device_new_with_object_path (values[0]);
+	ret = cd_device_connect_sync (device, NULL, error);
+	if (!ret)
+		goto out;
 	profile = cd_profile_new_with_object_path (values[1]);
 	ret = cd_device_make_profile_default_sync (device, profile,
 						   NULL, error);
@@ -1151,8 +1199,18 @@ cd_util_delete_device (CdUtilPrivate *priv, gchar **values, GError **error)
 		g_set_error_literal (error,
 				     1, 0,
 				     "Not enough arguments, "
-				     "expected device id "
-				     "e.g. 'epson-stylus-800'");
+				     "expected device path "
+				     "e.g. '/org/devices/foo'");
+		goto out;
+	}
+
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
 		goto out;
 	}
 
@@ -1181,8 +1239,18 @@ cd_util_delete_profile (CdUtilPrivate *priv, gchar **values, GError **error)
 		g_set_error_literal (error,
 				     1, 0,
 				     "Not enough arguments, "
-				     "expected profile id "
-				     "e.g. 'epson-rgb'");
+				     "expected profile path "
+				     "e.g. '/org/profiles/bar'");
+		goto out;
+	}
+
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
 		goto out;
 	}
 
@@ -1216,6 +1284,16 @@ cd_util_profile_set_qualifier (CdUtilPrivate *priv, gchar **values, GError **err
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
 	profile = cd_profile_new_with_object_path (values[0]);
 	ret = cd_profile_set_qualifier_sync (profile, values[1],
 					     NULL, error);
@@ -1246,7 +1324,20 @@ cd_util_profile_set_filename (CdUtilPrivate *priv, gchar **values, GError **erro
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
 	profile = cd_profile_new_with_object_path (values[0]);
+	ret = cd_profile_connect_sync (profile, NULL, error);
+	if (!ret)
+		goto out;
 	ret = cd_profile_set_filename_sync (profile, values[1],
 					    NULL, error);
 	if (!ret)
@@ -1276,7 +1367,20 @@ cd_util_device_set_model (CdUtilPrivate *priv, gchar **values, GError **error)
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
 	device = cd_device_new_with_object_path (values[0]);
+	ret = cd_device_connect_sync (device, NULL, error);
+	if (!ret)
+		goto out;
 	ret = cd_device_set_model_sync (device, values[1],
 					NULL, error);
 	if (!ret)
@@ -1291,13 +1395,15 @@ out:
  * cd_util_device_get_default_profile:
  **/
 static gboolean
-cd_util_device_get_default_profile (CdUtilPrivate *priv, gchar **values, GError **error)
+cd_util_device_get_default_profile (CdUtilPrivate *priv,
+				    gchar **values,
+				    GError **error)
 {
 	CdDevice *device = NULL;
 	CdProfile *profile = NULL;
 	gboolean ret = TRUE;
 
-	if (g_strv_length (values) < 2) {
+	if (g_strv_length (values) < 1) {
 		ret = FALSE;
 		g_set_error_literal (error,
 				     1, 0,
@@ -1307,12 +1413,32 @@ cd_util_device_get_default_profile (CdUtilPrivate *priv, gchar **values, GError
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
 	device = cd_device_new_with_object_path (values[0]);
+	ret = cd_device_connect_sync (device, NULL, error);
+	if (!ret)
+		goto out;
 	profile = cd_device_get_default_profile (device);
 	if (profile == NULL) {
 		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "There is no assigned profile for %s",
+			     values[0]);
 		goto out;
 	}
+	ret = cd_profile_connect_sync (profile, NULL, error);
+	if (!ret)
+		goto out;
 	cd_util_show_profile (profile);
 out:
 	if (device != NULL)
@@ -1341,7 +1467,20 @@ cd_util_device_set_vendor (CdUtilPrivate *priv, gchar **values, GError **error)
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
 	device = cd_device_new_with_object_path (values[0]);
+	ret = cd_device_connect_sync (device, NULL, error);
+	if (!ret)
+		goto out;
 	ret = cd_device_set_vendor_sync (device, values[1],
 					 NULL, error);
 	if (!ret)
@@ -1371,7 +1510,20 @@ cd_util_device_set_serial (CdUtilPrivate *priv, gchar **values, GError **error)
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
 	device = cd_device_new_with_object_path (values[0]);
+	ret = cd_device_connect_sync (device, NULL, error);
+	if (!ret)
+		goto out;
 	ret = cd_device_set_serial_sync (device, values[1],
 					 NULL, error);
 	if (!ret)
@@ -1401,7 +1553,20 @@ cd_util_device_set_kind (CdUtilPrivate *priv, gchar **values, GError **error)
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
 	device = cd_device_new_with_object_path (values[0]);
+	ret = cd_device_connect_sync (device, NULL, error);
+	if (!ret)
+		goto out;
 	ret = cd_device_set_kind_sync (device, cd_device_kind_from_string (values[1]),
 				       NULL, error);
 	if (!ret)
@@ -1434,7 +1599,20 @@ cd_util_device_get_profile_for_qualifiers (CdUtilPrivate *priv,
 		goto out;
 	}
 
+	/* check is valid object path */
+	if (!g_variant_is_object_path (values[0])) {
+		ret = FALSE;
+		g_set_error (error,
+			     1, 0,
+			     "Not a valid object path: %s",
+			     values[0]);
+		goto out;
+	}
+
 	device = cd_device_new_with_object_path (values[0]);
+	ret = cd_device_connect_sync (device, NULL, error);
+	if (!ret)
+		goto out;
 	profile = cd_device_get_profile_for_qualifiers_sync (device,
 							     (const gchar **) values,
 							     NULL,
