@@ -375,12 +375,8 @@ cd_main_device_add (CdDevice *device,
 		ret = cd_device_db_add (device_db,
 					cd_device_get_id (device),
 					&error_local);
-		if (!ret) {
-			g_warning ("CdMain: failed to add device %s to db: %s",
-				   cd_device_get_object_path (device),
-				   error_local->message);
-			g_clear_error (&error_local);
-		}
+		if (!ret)
+			goto out;
 	}
 
 	/* profile is no longer valid */
@@ -393,7 +389,7 @@ cd_main_device_add (CdDevice *device,
 
 	/* auto add profiles from the database */
 	cd_main_device_auto_add_profiles (device);
-
+out:
 	return ret;
 }
 
@@ -1390,6 +1386,7 @@ cd_main_add_sensor (CdSensor *sensor)
 	/* register on bus */
 	ret = cd_main_sensor_register_on_bus (sensor, &error);
 	if (!ret) {
+		g_ptr_array_remove (sensors, sensor);
 		g_warning ("CdMain: failed to emit SensorAdded: %s",
 			   error->message);
 		g_error_free (error);
